@@ -6,6 +6,7 @@ from boxx import imread
 import os
 import cv2
 import yaml
+import copy
 import pickle
 import numpy as np
 from glob import glob
@@ -58,9 +59,6 @@ class Cam(dict):
             d.pop("img")
             self[key] = d
 
-        self.valid_keys = set(
-            [key for key in self if len(self[key].get("image_points", {}))]
-        )
         self.image_points = self._get_points_for_cv2("image_points")
         self.object_points = self._get_points_for_cv2("object_points")
 
@@ -97,6 +95,10 @@ class Cam(dict):
                 boxx.imsave(visdir + "/" + key + ".jpg", vis)
                 d.pop("img")
 
+    @property
+    def valid_keys(self):
+        return set([key for key in self if len(self[key].get("image_points", {}))])
+
     def _cache(self, do_cache=False):
         cache_path = TEMP + "/calibrating-cache-" + self.name + ".pkl"
         if self.enable_cache and os.path.isfile(cache_path):
@@ -298,7 +300,7 @@ class Cam(dict):
                 with open(path_or_str) as f:
                     dic = yaml.safe_load(f)
         else:
-            dic = path_or_str_or_dict
+            dic = copy.deepcopy(path_or_str_or_dict)
         dic["K"] = intrinsic_format_conversion(dic)
         dic["D"] = np.float64(dic["D"])
         dic["xy"] = tuple(dic["xy"])
